covI: Compute the covariance between two wavelet periodogram
ordinates at the same scale, but different time locations.
Description
Computes $cov(I_{\ell, m}, I_{\ell, n})$ using the formula
given in Nason (2012) in Theorem 1. Note: one usually should
use the covIwrap function for efficiency.
Usage
covI(II, m, n, ll, ThePsiJ)
Arguments
II
Actually the *spectral* estimate S, not the periodogram
values. This is for an assumed stationary series, so this is just
a vector of length J, one for each scale of S.
m
Time location m
n
Time location n
ll
Scale of the raw wavelet periodogram
ThePsiJ
Autocorrelation wavelet corresponding to the
wavelet that computed the raw peridogram (also assumed
to underlie the time series
Value
References
Nason, G.P. (2013) A test for second-order stationarity and
approximate confidence intervals for localized autocovariances
for locally stationary time series. J. R. Statist. Soc. B,
75, 879-904.