Learn R Programming

locits (version 1.7.1)

print.hwtANYN: Print out a hwtANYN class object, eg from the link{hwt} function.

Description

Prints out very basic information on an object that represents a Haar wavelet transform of a data set of non-dyadic length.

Usage

"print"(x, ...)

Arguments

x
The object you wish to print.
...
Other arguments

Value

summary.hwtANYN function as its last action. So, the return from this function is the return from summary.hwtANYN

References

Nason, G.P. (2013) A test for second-order stationarity and approximate confidence intervals for localized autocovariances for locally stationary time series. J. R. Statist. Soc. B, 75, 879-904.

See Also

hwt, summary.hwtANYN

Examples

Run this code
#
# Generate test vector of length 5
#
v2 <- rnorm(5)
#
# Compute Haar wavelet transform
#
v2.hwt <- hwt(v2)
#
# Print out the answer
#
print(v2.hwt)
#Class 'hwtANYN' : Haar Wavelet for Arbitrary Length Data object:
#       ~~~~~~~  : List with 5 components with names
#		   c d nlevels type reindex 
#
#
#summary(.):
#----------
#Levels:  2 
#Filter was: Haar
#Transform type:  wavelet 
#Object was reindex to match wd:  FALSE 

Run the code above in your browser using DataLab