Learn R Programming

locits (version 1.4)

print.lacfCI: Print basic information about a lacfCI object.

Description

Prints basic information about a lacfCI object, which contains information on confidence intervals for localized autocovariance.

Usage

## S3 method for class 'lacfCI':
print(x, ...)

Arguments

x
The lacfCI object.
...
Other arguments

Value

  • The last action of this function is to compute summary.tos so the return code is whatever that function returns.

References

Nason, G.P. (2013) A test for second-order stationarity and approximate confidence intervals for localized autocovariances for locally stationary time series. J. R. Statist. Soc. B, 75, 879-904.

See Also

summary.lacfCI, Rvarlacf

Examples

Run this code
#
# See example on Rvarlacf help page

Run the code above in your browser using DataLab