Learn R Programming

locits (version 1.7.1)

print.tosANYN: Print out a tosANYN class object, eg from the link{hwtos} function.

Description

Prints out very basic information on an object that represents the output from a test of stationarity.

Usage

"print"(x, ...)

Arguments

x
The object you wish to print.
...
Other arguments

Value

summary.tosANYN function as its last action. So, the return from this function is the return from summary.tosANYN

References

Nason, G.P. (2013) A test for second-order stationarity and approximate confidence intervals for localized autocovariances for locally stationary time series. J. R. Statist. Soc. B, 75, 879-904.

See Also

hwtos,summary.tosANYN

Examples

Run this code
#
# See example at end of help for hwtos
#

Run the code above in your browser using DataLab