Learn R Programming

locits (version 1.7.1)

summary.hwtANYN: Summarize the results of a Haar wavelet transform object computed from an arbitrary length vector.

Description

This function summarizes the results of a hwtANYN object that contains the results of a Haar wavelet transform that had been carried out on an original vector of (potentially) non-dyadic length.

Usage

"summary"(object, ...)

Arguments

object
The object that you want a summary of. The object might be the results from, e.g., hwt function.
...
Other arguments

Value

References

Nason, G.P. (2013) A test for second-order stationarity and approximate confidence intervals for localized autocovariances for locally stationary time series. J. R. Statist. Soc. B, 75, 879-904.

See Also

hwt, print.hwtANYN

Examples

Run this code
#
# See help for print.hwtANYN 

Run the code above in your browser using DataLab