Usage
Rvarlacf(x, nz, filter.number = 1, family = "DaubExPhase",
smooth.dev = var, AutoReflect = TRUE, lag.max = NULL,
WPsmooth.type = "RM", binwidth = 0, mkcoefOBJ, ThePsiJ,
Cverbose = 0, verbose = 0, OPLENGTH = 10^5, var.lag.max = 3,
ABB.tol = 0.1, ABB.plot.it = FALSE, ABB.verbose = 0,
ABB.maxits = 10, ...)Arguments
x
The time series you wish to analyze
nz
The time point at which you wish to compute the
localized autocovariance for.
filter.number
The analysis wavelet for many things, including
smoothing. See wd for information on the various types.
family
The analysis wavelet family. See wd again.
smooth.dev
The deviance function used to perform smoothing of
the evolutionary wavelet spectrum.
AutoReflect
The internal wavelet transforms assume periodic
boundary conditions. However, most time series are not
periodic (in terms of their support, e.g. the series at time
1 is not normally anywhere near the value of the series at
time T). This argument, if <
lag.max
The maximum number of lags to compute the localized
autocovariance for. The default is the same as in the
regular acf function.
WPsmooth.type
The type of smoothing of the evolutionary
wavelet spectrum and the localized autocovariance. See the
arguments to lacf. binwidth
The smoothing bandwidth associated with the
smoothing controlled by WPsmooth.type. If this value
is zero then the binwidth is computed automatically
by the routine. And if verbose>0 the value is also
printed.
mkcoefOBJ
Optionally, the appropriate discrete wavelet
transform object can be supplied. If it is not supplied
then the routine automatically computes it. There is a small
saving in providing it, so for everyday use probably not worth
it.
ThePsiJ
As for mkcoefOBJ but the autocorrelation
wavelet object.
Cverbose
If positive integer then the called C code produces
verbose messages. Useful for debugging.
verbose
If positive integer >0 then useful messages are printed.
Higher values give more information.
OPLENGTH
Parameter that controls storage allocated to
the PsiJ routine. It is possible, for large time series,
you might be asked to increase this value.
var.lag.max
Number of lags that you want to compute confidence
intervals for. Usually, it is quick to compute for more lags,
so this could usually be set to be the value of lag.max
above.
ABB.tol
The routine selects the automatic bandwidth via a golden section
search. This argument controls the optimization tolerance.
ABB.plot.it
Whether or not to plot the iterations of the
automatic bandwidth golden section search. (TRUE/FALSE)
ABB.verbose
Positive integer controlling the amount of
detail from the automatic bandwidth golden section search
algorithm. If zero nothing is produced.
ABB.maxits
The maximum number of iterations in the automatic bandwidth
golden section search.