Learn R Programming

locits (version 1.4)

print.tos: Print out a tos class object, eg from the link{hwtos2} function.

Description

Prints out very basic information on an object that represents the output from a test of stationarity.

Usage

## S3 method for class 'tos':
print(x, ...)

Arguments

x
The object you wish to print.
...
Other arguments

Value

  • This function calls the summary.tos function as its last action. So, the return from this function is the return from summary.tos

References

Nason, G.P. (2013) A test for second-order stationarity and approximate confidence intervals for localized autocovariances for locally stationary time series. J. R. Statist. Soc. B, 75, 879-904.

See Also

hwtos2

Examples

Run this code
#
# See example at end of help for hwtos2
#

Run the code above in your browser using DataLab